## about.py - Information about Guppy
## Copyright (C) 2005 Tony Tsui <tsui.tony@gmail.com>
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

APP_NAME = 'Guppy'
VERSION = '0.0.91'
DESCRIPTION='Topfield PVR File Downloader'
AUTHOR = 'Tony Tsui'
AUTHOR_EMAIL = 'tsui.tony@gmail.com'
# List of additional contributors. Format: 'Name Email'
CONTRIBUTORS = [ 'Tango Desktop Project http://tango-project.org' ]
WEBSITE = 'http://guppy.nongnu.org'
COPYRIGHT = 'Copyright (C) 2005-2006 Tony Tsui'
LICENSE = 'GNU Public License & CC-by-SA 2.5 License'
